# Protorepo
For python support in PyCharm [read here](https://youtrack.jetbrains.com/issue/PY-27111/Please-add-protobuf-autocompletion-support)

Solution:
- [Mypy](https://github.com/dropbox/mypy-protobuf)
- [Typeshed](https://github.com/python/typeshed)